@@ -1,63 +1,25 @@
 package Business::CyberSource::Request::AuthReversal;
-use 5.008;
 use strict;
 use warnings;
-use Carp;
+use namespace::autoclean;
 
-our $VERSION = '0.004003'; # VERSION
+our $VERSION = '0.004004'; # VERSION
 
 use Moose;
-use namespace::autoclean;
 with qw(
 	Business::CyberSource::Request::Role::Common
 	Business::CyberSource::Request::Role::PurchaseInfo
 	Business::CyberSource::Request::Role::FollowUp
 );
 
-use Business::CyberSource::Response;
-use MooseX::StrictConstructor;
-
-sub submit {
+before serialize => sub {
 	my $self = shift;
 
 	$self->_request_data->{ccAuthReversalService}{run} = 'true';
 	$self->_request_data->{ccAuthReversalService}{authRequestID}
 		= $self->request_id
 		;
-
-	my $r = $self->_build_request;
-
-	my $res;
-	if ( $r->{decision} eq 'ACCEPT' ) {
-		$res
-			= Business::CyberSource::Response
-			->with_traits(qw{
-				Business::CyberSource::Response::Role::Accept
-				Business::CyberSource::Response::Role::ProcessorResponse
-			})
-			->new({
-				request_id     => $r->{requestID},
-				decision       => $r->{decision},
-				# quote reason_code to stringify from BigInt
-				reason_code    => "$r->{reasonCode}",
-				request_token  => $r->{requestToken},
-				reference_code => $r->{merchantReferenceCode},
-				currency       => $r->{purchaseTotals}->{currency},
-				datetime       => $r->{ccAuthReversalReply}->{requestDateTime},
-				amount         => $r->{ccAuthReversalReply}->{amount},
-				request_specific_reason_code =>
-					"$r->{ccAuthReversalReply}->{reasonCode}",
-				processor_response =>
-					$r->{ccAuthReversalReply}->{processorResponse},
-			})
-			;
-	}
-	else {
-		$res = $self->_handle_decision( $r );
-	}
-
-	return $res;
-}
+};
 
 __PACKAGE__->meta->make_immutable;
 1;
@@ -74,7 +36,7 @@ Business::CyberSource::Request::AuthReversal - CyberSource Reverse Authorization
 
 =head1 VERSION
 
-version 0.004003
+version 0.004004
 
 =head1 SYNOPSIS
 
@@ -102,22 +64,6 @@ Reader: foreign_amount
 
 Type: MooseX::Types::Common::Numeric::PositiveOrZeroNum
 
-=head2 client_env
-
-Reader: client_env
-
-Type: Str
-
-Additional documentation: provided by the library
-
-=head2 cybs_wsdl
-
-Reader: cybs_wsdl
-
-Type: MooseX::Types::Path::Class::File
-
-Additional documentation: provided by the library
-
 =head2 comments
 
 Reader: comments
@@ -146,36 +92,20 @@ Reader: password
 
 Type: MooseX::Types::Common::String::NonEmptyStr
 
-This attribute is required.
-
-Additional documentation: your SOAP transaction key
-
 =head2 production
 
 Reader: production
 
 Type: Bool
 
-This attribute is required.
-
-Additional documentation: 0: test server. 1: production server
-
 =head2 request_id
 
 Reader: request_id
 
-Type: MooseX::Types::Varchar::Varchar[29]
+Type: __ANON__
 
 This attribute is required.
 
-=head2 cybs_api_version
-
-Reader: cybs_api_version
-
-Type: Str
-
-Additional documentation: provided by the library
-
 =head2 exchange_rate
 
 Reader: exchange_rate
@@ -200,19 +130,7 @@ Additional documentation: Grand total for the order. You must include either thi
 
 Reader: username
 
-Type: MooseX::Types::Varchar::Varchar[30]
-
-This attribute is required.
-
-Additional documentation: Your CyberSource merchant ID. Use the same merchantID for evaluation, testing, and production
-
-=head2 cybs_xsd
-
-Reader: cybs_xsd
-
-Type: MooseX::Types::Path::Class::File
-
-Additional documentation: provided by the library
+Type: __ANON__
 
 =head2 foreign_currency
 
@@ -226,24 +144,10 @@ Additional documentation: Billing currency returned by the DCC service. For the
 
 Reader: reference_code
 
-Type: MooseX::Types::Varchar::Varchar[50]
+Type: MooseX::Types::CyberSource::_VarcharFifty
 
 This attribute is required.
 
-=head2 client_name
-
-Reader: client_name
-
-Type: Str
-
-Additional documentation: provided by the library
-
-=head2 client_version
-
-Reader: client_version
-
-Type: Str
-
 =head2 items
 
 Reader: items
