@@ -1,11 +1,9 @@
 package Business::CyberSource::Request::Authorization;
-use 5.008;
 use strict;
 use warnings;
 use namespace::autoclean;
-use Carp;
 
-our $VERSION = '0.004003'; # VERSION
+our $VERSION = '0.004004'; # VERSION
 
 use Moose;
 with qw(
@@ -17,83 +15,10 @@ with qw(
 	Business::CyberSource::Request::Role::DCC
 );
 
-use Business::CyberSource::Response;
-use MooseX::StrictConstructor;
-
-sub submit {
+before serialize => sub {
 	my $self = shift;
-
 	$self->_request_data->{ccAuthService}{run} = 'true';
-
-	my $r = $self->_build_request;
-
-	my $res;
-	if ( $r->{decision} eq 'ACCEPT' or $r->{decision} eq 'REJECT' ) {
-		my @traits = qw(Business::CyberSource::Response::Role::Authorization);
-
-		my $e = { };
-
-		if ( $r->{decision} eq 'ACCEPT' ) {
-			push( @traits, 'Business::CyberSource::Response::Role::Accept' );
-			$e->{currency      } = $r->{purchaseTotals}{currency};
-			$e->{amount        } = $r->{ccAuthReply}->{amount};
-			$e->{datetime      } = $r->{ccAuthReply}{authorizedDateTime};
-			$e->{reference_code} = $r->{merchantReferenceCode};
-			$e->{request_specific_reason_code}
-				= "$r->{ccAuthReply}->{reasonCode}";
-		}
-
-		if ( $r->{ccAuthReply} ) {
-
-			$e->{auth_code}
-				=  $r->{ccAuthReply}{authorizationCode }
-				if $r->{ccAuthReply}{authorizationCode }
-				;
-
-
-			if ( $r->{ccAuthReply}{cvCode}
-					&& $r->{ccAuthReply}{cvCodeRaw}
-				) {
-				$e->{cv_code}     = $r->{ccAuthReply}{cvCode};
-				$e->{cv_code_raw} = $r->{ccAuthReply}{cvCodeRaw};
-			}
-
-			if ( $r->{ccAuthReply}{avsCode}
-					&& $r->{ccAuthReply}{avsCodeRaw}
-				) {
-				$e->{avs_code}     = $r->{ccAuthReply}{avsCode};
-				$e->{avs_code_raw} = $r->{ccAuthReply}{avsCodeRaw};
-			}
-			if ( $r->{ccAuthReply}{processorResponse} ) {
-				$e->{processor_response}
-					= $r->{ccAuthReply}{processorResponse}
-					;
-			}
-
-			if ( $r->{ccAuthReply}->{authRecord} ) {
-				$e->{auth_record} = $r->{ccAuthReply}->{authRecord};
-			}
-		}
-
-		$res
-			= Business::CyberSource::Response
-			->with_traits( @traits )
-			->new({
-				request_id     => $r->{requestID},
-				decision       => $r->{decision},
-				# quote reason_code to stringify from BigInt
-				reason_code    => "$r->{reasonCode}",
-				request_token  => $r->{requestToken},
-			%{$e},
-			})
-			;
-	}
-	else {
-		croak 'decision defined, but not sane: ' . $r->{decision};
-	}
-
-	return $res;
-}
+};
 
 __PACKAGE__->meta->make_immutable;
 1;
@@ -110,7 +35,7 @@ Business::CyberSource::Request::Authorization - CyberSource Authorization Reques
 
 =head1 VERSION
 
-version 0.004003
+version 0.004004
 
 =head1 SYNOPSIS
 
@@ -194,22 +119,6 @@ Reader: ignore_cv_result
 
 Type: Bool
 
-=head2 client_env
-
-Reader: client_env
-
-Type: Str
-
-Additional documentation: provided by the library
-
-=head2 cybs_wsdl
-
-Reader: cybs_wsdl
-
-Type: MooseX::Types::Path::Class::File
-
-Additional documentation: provided by the library
-
 =head2 comments
 
 Reader: comments
@@ -220,7 +129,7 @@ Type: Str
 
 Reader: state
 
-Type: MooseX::Types::Varchar::Varchar[2]
+Type: __ANON__
 
 Additional documentation: State or province of the billing address. Use the two-character codes. alias: C<province>
 
@@ -248,26 +157,14 @@ Reader: password
 
 Type: MooseX::Types::Common::String::NonEmptyStr
 
-This attribute is required.
-
-Additional documentation: your SOAP transaction key
-
 =head2 postal_code
 
 Reader: postal_code
 
-Type: MooseX::Types::Varchar::Varchar[10]
+Type: MooseX::Types::CyberSource::_VarcharTen
 
 Additional documentation: Postal code for the billing address. The postal code must consist of 5 to 9 digits. Required if C<country> is "US" or "CA"alias: C<postal_code>
 
-=head2 cybs_api_version
-
-Reader: cybs_api_version
-
-Type: Str
-
-Additional documentation: provided by the library
-
 =head2 ignore_export_result
 
 Reader: ignore_export_result
@@ -286,17 +183,7 @@ Additional documentation: Card Verification Numbers
 
 Reader: phone_number
 
-Type: MooseX::Types::Varchar::Varchar[20]
-
-=head2 cc_exp_month
-
-Reader: cc_exp_month
-
-Type: MooseX::Types::Varchar::Varchar[2]
-
-This attribute is required.
-
-Additional documentation: Two-digit month that the credit card expires in. Format: MM.
+Type: MooseX::Types::CyberSource::_VarcharTwenty
 
 =head2 total
 
@@ -306,15 +193,21 @@ Type: MooseX::Types::Common::Numeric::PositiveOrZeroNum
 
 Additional documentation: Grand total for the order. You must include either this field or item_#_unitPrice in your request
 
+=head2 cc_exp_month
+
+Reader: cc_exp_month
+
+Type: __ANON__
+
+This attribute is required.
+
+Additional documentation: Two-digit month that the credit card expires in. Format: MM.
+
 =head2 username
 
 Reader: username
 
-Type: MooseX::Types::Varchar::Varchar[30]
-
-This attribute is required.
-
-Additional documentation: Your CyberSource merchant ID. Use the same merchantID for evaluation, testing, and production
+Type: __ANON__
 
 =head2 credit_card
 
@@ -338,7 +231,7 @@ Additional documentation: Type of card to authorize
 
 Reader: street2
 
-Type: MooseX::Types::Varchar::Varchar[60]
+Type: MooseX::Types::CyberSource::_VarcharSixty
 
 Additional documentation: Second line of the billing street address.
 
@@ -346,7 +239,7 @@ Additional documentation: Second line of the billing street address.
 
 Reader: reference_code
 
-Type: MooseX::Types::Varchar::Varchar[50]
+Type: MooseX::Types::CyberSource::_VarcharFifty
 
 This attribute is required.
 
@@ -354,13 +247,13 @@ This attribute is required.
 
 Reader: street3
 
-Type: MooseX::Types::Varchar::Varchar[60]
+Type: MooseX::Types::CyberSource::_VarcharSixty
 
 Additional documentation: Third line of the billing street address.
 
 =head2 score_threshold
 
-Type: Int
+Type: MooseX::Types::Common::String::NumericCode
 
 =head2 ignore_avs_result
 
@@ -372,7 +265,7 @@ Type: Bool
 
 Reader: last_name
 
-Type: MooseX::Types::Varchar::Varchar[60]
+Type: MooseX::Types::CyberSource::_VarcharSixty
 
 This attribute is required.
 
@@ -398,7 +291,7 @@ This attribute is required.
 
 Reader: city
 
-Type: MooseX::Types::Varchar::Varchar[50]
+Type: MooseX::Types::CyberSource::_VarcharFifty
 
 This attribute is required.
 
@@ -410,15 +303,11 @@ Reader: production
 
 Type: Bool
 
-This attribute is required.
-
-Additional documentation: 0: test server. 1: production server
-
 =head2 street4
 
 Reader: street4
 
-Type: MooseX::Types::Varchar::Varchar[60]
+Type: MooseX::Types::CyberSource::_VarcharSixty
 
 Additional documentation: Fourth line of the billing street address.
 
@@ -458,40 +347,32 @@ Reader: ignore_validate_result
 
 Type: Bool
 
-=head2 full_name
-
-Reader: full_name
-
-Type: MooseX::Types::Varchar::Varchar[60]
-
 =head2 street1
 
 Reader: street1
 
-Type: MooseX::Types::Varchar::Varchar[60]
+Type: MooseX::Types::CyberSource::_VarcharSixty
 
 This attribute is required.
 
 Additional documentation: First line of the billing street address as it appears on the credit card issuer's records. alias: C<street1>
 
+=head2 full_name
+
+Reader: full_name
+
+Type: MooseX::Types::CyberSource::_VarcharSixty
+
 =head2 cc_exp_year
 
 Reader: cc_exp_year
 
-Type: MooseX::Types::Varchar::Varchar[4]
+Type: __ANON__
 
 This attribute is required.
 
 Additional documentation: Four-digit year that the credit card expires in. Format: YYYY.
 
-=head2 cybs_xsd
-
-Reader: cybs_xsd
-
-Type: MooseX::Types::Path::Class::File
-
-Additional documentation: provided by the library
-
 =head2 dcc_indicator
 
 Reader: dcc_indicator
@@ -512,23 +393,19 @@ Reader: ignore_dav_result
 
 Type: Bool
 
-=head2 client_name
-
-Reader: client_name
-
-Type: Str
-
-Additional documentation: provided by the library
-
 =head2 decline_avs_flags
 
 Type: ArrayRef[MooseX::Types::CyberSource::AVSResult]
 
-=head2 client_version
+=head2 first_name
 
-Reader: client_version
+Reader: first_name
 
-Type: Str
+Type: MooseX::Types::CyberSource::_VarcharSixty
+
+This attribute is required.
+
+Additional documentation: Customer's first name.The value should be the same as the one that is on the card.
 
 =head2 items
 
@@ -536,16 +413,6 @@ Reader: items
 
 Type: ArrayRef[MooseX::Types::CyberSource::Item]
 
-=head2 first_name
-
-Reader: first_name
-
-Type: MooseX::Types::Varchar::Varchar[60]
-
-This attribute is required.
-
-Additional documentation: Customer's first name.The value should be the same as the one that is on the card.
-
 =head1 METHODS
 
 =head2 new
