@@ -1,62 +1,25 @@
 package Business::CyberSource::Request::Capture;
-use 5.008;
 use strict;
 use warnings;
-use Carp;
+use namespace::autoclean;
 
-our $VERSION = '0.004003'; # VERSION
+our $VERSION = '0.004004'; # VERSION
 
 use Moose;
-use namespace::autoclean;
 with qw(
 	Business::CyberSource::Request::Role::Common
 	Business::CyberSource::Request::Role::FollowUp
 	Business::CyberSource::Request::Role::DCC
 );
 
-use Business::CyberSource::Response;
-use MooseX::StrictConstructor;
-
-sub submit {
+before serialize => sub {
 	my $self = shift;
 
 	$self->_request_data->{ccCaptureService}{run} = 'true';
 	$self->_request_data->{ccCaptureService}{authRequestID}
 		= $self->request_id
 		;
-
-	my $r = $self->_build_request;
-
-	my $res;
-	if ( $r->{decision} eq 'ACCEPT' ) {
-		$res
-			= Business::CyberSource::Response
-			->with_traits(qw{
-				Business::CyberSource::Response::Role::Accept
-				Business::CyberSource::Response::Role::ReconciliationID
-			})
-			->new({
-				request_id     => $r->{requestID},
-				decision       => $r->{decision},
-				# quote reason_code to stringify from BigInt
-				reason_code    => "$r->{reasonCode}",
-				reference_code => $r->{merchantReferenceCode},
-				request_token  => $r->{requestToken},
-				currency       => $r->{purchaseTotals}->{currency},
-				datetime       => $r->{ccCaptureReply}->{requestDateTime},
-				amount         => $r->{ccCaptureReply}->{amount},
-				reconciliation_id => $r->{ccCaptureReply}->{reconciliationID},
-				request_specific_reason_code =>
-					"$r->{ccCaptureReply}->{reasonCode}",
-			})
-			;
-	}
-	else {
-		$res = $self->_handle_decision( $r );
-	}
-
-	return $res;
-}
+};
 
 __PACKAGE__->meta->make_immutable;
 1;
@@ -73,7 +36,7 @@ Business::CyberSource::Request::Capture - CyberSource Capture Request Object
 
 =head1 VERSION
 
-version 0.004003
+version 0.004004
 
 =head1 SYNOPSIS
 
@@ -99,22 +62,6 @@ Reader: foreign_amount
 
 Type: MooseX::Types::Common::Numeric::PositiveOrZeroNum
 
-=head2 client_env
-
-Reader: client_env
-
-Type: Str
-
-Additional documentation: provided by the library
-
-=head2 cybs_wsdl
-
-Reader: cybs_wsdl
-
-Type: MooseX::Types::Path::Class::File
-
-Additional documentation: provided by the library
-
 =head2 comments
 
 Reader: comments
@@ -135,18 +82,6 @@ Reader: password
 
 Type: MooseX::Types::Common::String::NonEmptyStr
 
-This attribute is required.
-
-Additional documentation: your SOAP transaction key
-
-=head2 cybs_api_version
-
-Reader: cybs_api_version
-
-Type: Str
-
-Additional documentation: provided by the library
-
 =head2 total
 
 Reader: total
@@ -159,17 +94,13 @@ Additional documentation: Grand total for the order. You must include either thi
 
 Reader: username
 
-Type: MooseX::Types::Varchar::Varchar[30]
-
-This attribute is required.
-
-Additional documentation: Your CyberSource merchant ID. Use the same merchantID for evaluation, testing, and production
+Type: __ANON__
 
 =head2 reference_code
 
 Reader: reference_code
 
-Type: MooseX::Types::Varchar::Varchar[50]
+Type: MooseX::Types::CyberSource::_VarcharFifty
 
 This attribute is required.
 
@@ -187,15 +118,11 @@ Reader: production
 
 Type: Bool
 
-This attribute is required.
-
-Additional documentation: 0: test server. 1: production server
-
 =head2 request_id
 
 Reader: request_id
 
-Type: MooseX::Types::Varchar::Varchar[29]
+Type: __ANON__
 
 This attribute is required.
 
@@ -211,14 +138,6 @@ Reader: exchange_rate_timestamp
 
 Type: Str
 
-=head2 cybs_xsd
-
-Reader: cybs_xsd
-
-Type: MooseX::Types::Path::Class::File
-
-Additional documentation: provided by the library
-
 =head2 dcc_indicator
 
 Reader: dcc_indicator
@@ -233,20 +152,6 @@ Type: MooseX::Types::Locale::Currency::CurrencyCode
 
 Additional documentation: Billing currency returned by the DCC service. For the possible values, see the ISO currency codes
 
-=head2 client_name
-
-Reader: client_name
-
-Type: Str
-
-Additional documentation: provided by the library
-
-=head2 client_version
-
-Reader: client_version
-
-Type: Str
-
 =head2 items
 
 Reader: items
