@@ -4,10 +4,11 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.004003'; # VERSION
+our $VERSION = '0.004004'; # VERSION
 
 use Moose::Role;
-use MooseX::Types::Moose qw( Bool ArrayRef Int );
+use MooseX::Types::Moose qw( Bool ArrayRef );
+use MooseX::Types::Common::String 0.001005 qw( NumericCode );
 use MooseX::Types::CyberSource qw( AVSResult );
 
 has ignore_avs_result => (
@@ -94,7 +95,7 @@ has decline_avs_flags => (
 has score_threshold => (
 	predicate => 'has_score_threshold',
 	required  => 0,
-	isa       => Int,
+	isa       => NumericCode,
 	trigger  => sub {
 		my $self = shift;
 		$self->_request_data->{businessRules}{scoreThreshold}
@@ -116,7 +117,7 @@ Business::CyberSource::Request::Role::BusinessRules - Business Rules Role
 
 =head1 VERSION
 
-version 0.004003
+version 0.004004
 
 =head1 BUGS
 
