@@ -5,81 +5,37 @@ use warnings;
 use Carp;
 use namespace::autoclean;
 
-our $VERSION = '0.004003'; # VERSION
+our $VERSION = '0.004004'; # VERSION
 
 use Moose::Role;
 use MooseX::Types::Moose   qw( HashRef Str );
-use MooseX::Types::Varchar qw( Varchar );
 use MooseX::Types::URI     qw( Uri     );
+use MooseX::Types::Path::Class qw( File Dir );
 use MooseX::SetOnce 0.200001;
 
 with qw(
-	Business::CyberSource
-	Business::CyberSource::Request::Role::PurchaseInfo
 	Business::CyberSource::Request::Role::Credentials
+	Business::CyberSource::Request::Role::PurchaseInfo
 	Business::CyberSource::Role::MerchantReferenceCode
 );
 
-requires 'submit';
+use Business::CyberSource::Client;
 
-use XML::Compile::SOAP::WSS 0.12;
-
-use XML::Compile::WSDL11;
-use XML::Compile::SOAP11;
-use XML::Compile::Transport::SOAPHTTP;
-
-sub _build_request {
+sub serialize {
 	my $self = shift;
-
-	my $wss = XML::Compile::SOAP::WSS->new( version => '1.1' );
-
-	my $wsdl = XML::Compile::WSDL11->new( $self->cybs_wsdl->stringify );
-	$wsdl->importDefinitions( $self->cybs_xsd->stringify );
-
-	my $call = $wsdl->compileClient('runTransaction');
-
-	my $security = $wss->wsseBasicAuth( $self->username, $self->password );
-
-	my ( $answer, $trace ) = $call->(
-		wsse_Security         => $security,
-		merchantID            => $self->username,
-		clientEnvironment     => $self->client_env,
-		clientLibrary         => $self->client_name,
-		clientLibraryVersion  => $self->client_version,
-		merchantReferenceCode => $self->reference_code,
-		%{ $self->_request_data },
-	);
-
-	$self->_trace( $trace );
-
-	if ( $answer->{Fault} ) {
-		croak 'SOAP Fault: ' . $answer->{Fault}->{faultstring};
-	}
-
-	my $r = $answer->{result};
-
-	return $r;
+	return $self->_request_data;
 }
 
-sub _handle_decision {
-	my ( $self, $r ) = @_;
+sub submit {
+	my $self = shift;
 
-	my $res;
-	if ( $r->{decision} eq 'REJECT' ) {
-		$res
-			= Business::CyberSource::Response
-			->new({
-				decision      => $r->{decision},
-				request_id    => $r->{requestID},
-				reason_code   => "$r->{reasonCode}",
-				request_token => $r->{requestToken},
-			});
-	}
-	else {
-		croak 'decision defined, but not sane: ' . $r->{decision};
-	}
+	my $client = Business::CyberSource::Client->new({
+		username   => $self->username,
+		password   => $self->password,
+		production => $self->production,
+	});
 
-	return $res;
+	return $client->run_transaction( $self );
 }
 
 sub BUILD { ## no critic qw( Subroutines::RequireFinalReturn )
@@ -138,7 +94,17 @@ Business::CyberSource::Request::Role::Common - Request Role
 
 =head1 VERSION
 
-version 0.004003
+version 0.004004
+
+=head1 METHODS
+
+=head2 serialize
+
+returns a hashref suitable for passing to L<XML::Compile::SOAP>
+
+=head2 submit
+
+B<DEPRECATED> now calls L<Business::CyberSource::Client>
 
 =for Pod::Coverage BUILD
 
