@@ -4,12 +4,11 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.004003'; # VERSION
+our $VERSION = '0.004004'; # VERSION
 
 use Moose::Role;
 
-use MooseX::Types::CyberSource qw( AVSResult );
-use MooseX::Types::Varchar qw( Varchar );
+use MooseX::Types::CyberSource qw( AVSResult _VarcharTen );
 
 has avs_code => (
 	required => 0,
@@ -23,7 +22,7 @@ has avs_code_raw => (
 	required  => 0,
 	predicate => 'has_avs_code_raw',
 	is        => 'ro',
-	isa       => Varchar[10],
+	isa       => _VarcharTen,
 	documentation => 'AVS result code sent directly from the processor. '
 		. 'Returned only if a value is returned by the processor.',
 );
@@ -41,7 +40,7 @@ Business::CyberSource::Response::Role::AVS - AVS Role
 
 =head1 VERSION
 
-version 0.004003
+version 0.004004
 
 =head1 BUGS
 
