@@ -4,16 +4,16 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.004003'; # VERSION
+our $VERSION = '0.004004'; # VERSION
 
 use Moose::Role;
-use MooseX::Types::Varchar qw( Varchar );
+use MooseX::Types::CyberSource qw( _VarcharTen );
 
 has processor_response => (
 	required  => 0,
 	predicate => 'has_processor_response',
 	is        => 'ro',
-	isa       => Varchar[10],
+	isa       => _VarcharTen,
 );
 
 1;
@@ -29,7 +29,7 @@ Business::CyberSource::Response::Role::ProcessorResponse - Processor Response at
 
 =head1 VERSION
 
-version 0.004003
+version 0.004004
 
 =head1 BUGS
 
