@@ -5,15 +5,15 @@ use warnings;
 use Carp;
 use namespace::autoclean;
 
-our $VERSION = '0.004003'; # VERSION
+our $VERSION = '0.004004'; # VERSION
 
 use Moose::Role;
-use MooseX::Types::Varchar qw( Varchar );
+use MooseX::Types::CyberSource qw( _VarcharFifty );
 
 has reference_code => (
 	required => 1,
 	is       => 'ro',
-	isa      => Varchar[50],
+	isa      => _VarcharFifty,
 );
 
 1;
@@ -29,7 +29,7 @@ Business::CyberSource::Role::MerchantReferenceCode - Generic implementation of M
 
 =head1 VERSION
 
-version 0.004003
+version 0.004004
 
 =head1 BUGS
 
