@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.004003'; # VERSION
+our $VERSION = '0.004004'; # VERSION
 
 use MooseX::Types -declare => [ qw(
 	AVSResult
@@ -15,9 +15,16 @@ use MooseX::Types -declare => [ qw(
 	DCCIndicator
 	Decision
 	Item
+	_VarcharOne
+	_VarcharSeven
+	_VarcharTen
+	_VarcharTwenty
+	_VarcharFifty
+	_VarcharSixty
 ) ];
 
 use MooseX::Types::Common::Numeric qw( PositiveOrZeroNum );
+use MooseX::Types::Common::String  qw( NonEmptySimpleStr );
 use MooseX::Types::Moose qw( Int Num Str );
 use MooseX::Types::Structured qw( Dict Optional );
 use Locale::Country;
@@ -51,6 +58,7 @@ enum CardTypeCode, [ qw(
 
 enum CvIndicator, [ qw( 0 1 2 9 ) ];
 
+
 subtype Item,
 	as Dict[
 		unit_price   => PositiveOrZeroNum,
@@ -88,6 +96,35 @@ coerce CountryCode,
 
 enum DCCIndicator, [ qw( 1 2 3 ) ];
 
+subtype _VarcharOne,
+	as NonEmptySimpleStr,
+	where { length $_ <= 1 }
+	;
+
+subtype _VarcharSeven,
+	as NonEmptySimpleStr,
+	where { length $_ <= 7 }
+	;
+
+subtype _VarcharTen,
+	as NonEmptySimpleStr,
+	where { length $_ <= 10 }
+	;
+
+subtype _VarcharTwenty,
+	as NonEmptySimpleStr,
+	where { length $_ <= 20 }
+	;
+
+subtype _VarcharFifty,
+	as NonEmptySimpleStr,
+	where { length $_ <= 50 }
+	;
+
+subtype _VarcharSixty,
+	as NonEmptySimpleStr,
+	where { length $_ <= 60 }
+	;
 1;
 
 # ABSTRACT: Moose Types specific to CyberSource
@@ -102,7 +139,7 @@ MooseX::Types::CyberSource - Moose Types specific to CyberSource
 
 =head1 VERSION
 
-version 0.004003
+version 0.004004
 
 =head1 SYNOPSIS
 
